<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>ActionPackWindows</name>
    <message>
        <location filename="../actions/actionpackwindows/actionpackwindows.h" line="62"/>
        <source>Actions dealing with windows</source>
        <translation>Actions en rapport avec les fenêtres</translation>
    </message>
</context>
<context>
    <name>Actions::DataInputDefinition</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="49"/>
        <source>Question</source>
        <translatorcomment>Question</translatorcomment>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="50"/>
        <source>The question to ask</source>
        <translation>La question à poser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="53"/>
        <source>Data type</source>
        <translation>Type de donnée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="54"/>
        <source>The data type</source>
        <translation>Le type de donnée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="59"/>
        <source>Default value</source>
        <translation>Valeur par défaut</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="60"/>
        <source>The default value</source>
        <translation>La valeur par défaut</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="63"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="64"/>
        <source>The variable where to save the entered input</source>
        <translation>La variable où sauvegarder l&apos;entrée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="67"/>
        <source>Window title</source>
        <translation>Titre de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="68"/>
        <source>The title of the window</source>
        <translation>Le titre de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="71"/>
        <source>Window icon</source>
        <translation>Icône de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="72"/>
        <source>The window icon to use</source>
        <translation>L&apos;icône de fenêtre à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="74"/>
        <source>Select the icon to use</source>
        <translation>Sélectionnez l&apos;icône à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="75"/>
        <source>Images (*.jpg *.jpeg *.png *.bmp *.gif *.pbm *.pgm *.ppm *.xbm *.xpm)</source>
        <translation>Images (*.jpg *.jpeg *.png *.bmp *.gif *.pbm *.pgm *.ppm *.xbm *.xpm)</translation>
    </message>
</context>
<context>
    <name>Actions::MessageBoxDefinition</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="52"/>
        <source>Message</source>
        <translation>Message</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="53"/>
        <source>The text to show</source>
        <translation>Le texte à afficher</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="56"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="57"/>
        <source>The title to show</source>
        <translation>Le titre à afficher</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="60"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="61"/>
        <source>The icon to use</source>
        <translation>L&apos;icône à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="66"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="67"/>
        <source>The message box type</source>
        <translation>Le type de la boîte de dialogue</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="72"/>
        <source>Custom icon</source>
        <translation>Icône personnalisée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="73"/>
        <source>The custom icon to use</source>
        <translation>L&apos;icône personnalisée à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="75"/>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="82"/>
        <source>Select the icon to use</source>
        <translation>Sélectionnez l&apos;icône à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="76"/>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="83"/>
        <source>Images (*.jpg *.jpeg *.png *.bmp *.gif *.pbm *.pgm *.ppm *.xbm *.xpm)</source>
        <translation>Images (*.jpg *.jpeg *.png *.bmp *.gif *.pbm *.pgm *.ppm *.xbm *.xpm)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="79"/>
        <source>Window icon</source>
        <translation>Icône de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="80"/>
        <source>The window icon to use</source>
        <translation>L&apos;icône de fenêtre à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="86"/>
        <source>Text mode</source>
        <translation>Mode de texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="87"/>
        <source>The message box text mode</source>
        <translation>Le mode de texte de la boîte de dialogue</translation>
    </message>
    <message>
        <source>Yes-No action</source>
        <translation type="obsolete">Action Oui-Non</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="96"/>
        <source>If yes</source>
        <translation>Si oui</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="97"/>
        <source>What to do if the yes button is pressed</source>
        <translation>Ce qui doit être fait si le bouton Oui est pressé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="100"/>
        <source>If no</source>
        <translation>Si non</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="101"/>
        <source>What to do if the no button is pressed</source>
        <translation>Ce qui doit être fait si le bouton Non est pressé</translation>
    </message>
</context>
<context>
    <name>Actions::MultiDataInputDefinition</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="52"/>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="53"/>
        <source>The question to ask</source>
        <translation>La question à poser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="56"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="57"/>
        <source>The input mode</source>
        <translation>Le mode d&apos;entrée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="62"/>
        <source>Items</source>
        <translation>Éléments</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="63"/>
        <source>The item list</source>
        <translation>La liste d&apos;éléments</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="66"/>
        <source>Default value</source>
        <translation>Valeur par défaut</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="67"/>
        <source>The default value</source>
        <translation>La valeur par défaut</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="70"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="71"/>
        <source>The variable where to save the entered input</source>
        <translation>La variable où sauvegarder le ou les éléments choisis</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="74"/>
        <source>Window title</source>
        <translation>Titre de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="75"/>
        <source>The title of the window</source>
        <translation>Le titre de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="78"/>
        <source>Window icon</source>
        <translation>Icône de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="79"/>
        <source>The window icon to use</source>
        <translation>L&apos;icône de fenêtre à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="81"/>
        <source>Select the icon to use</source>
        <translation>Sélectionnez l&apos;icône à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="82"/>
        <source>Images (*.jpg *.jpeg *.png *.bmp *.gif *.pbm *.pgm *.ppm *.xbm *.xpm)</source>
        <translation>Images (*.jpg *.jpeg *.png *.bmp *.gif *.pbm *.pgm *.ppm *.xbm *.xpm)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="91"/>
        <source>Maximum choice count</source>
        <translation>Nombre maximum de choix</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="92"/>
        <source>The maximum number of choices that can be made</source>
        <translation>Le nombre maximum d&apos;éléments à sélectionner</translation>
    </message>
</context>
<context>
    <name>Actions::TextInputDefinition</name>
    <message>
        <source>Question</source>
        <translation type="obsolete">Question</translation>
    </message>
    <message>
        <source>The question to ask</source>
        <translation type="obsolete">La question à poser</translation>
    </message>
    <message>
        <source>Default value</source>
        <translation type="obsolete">Valeur par défaut</translation>
    </message>
    <message>
        <source>The default value</source>
        <translation type="obsolete">La valeur par défaut</translation>
    </message>
    <message>
        <source>Variable</source>
        <translation type="obsolete">Variable</translation>
    </message>
    <message>
        <source>The variable where to save the entered input</source>
        <translation type="obsolete">La variable où sauvegarder l&apos;entrée</translation>
    </message>
</context>
<context>
    <name>Actions::WindowConditionDefinition</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="49"/>
        <source>Window title</source>
        <translation>Titre de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="50"/>
        <source>The title of the window to find, you can use wildcards like * (any number of characters) or ? (one character) here</source>
        <translation>Le titre de la fenêtre à trouver, vous pouvez utiliser des wildcards comme * (tout caractère) ou ? (un seul caractère) ici</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="53"/>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="54"/>
        <source>The condition to wait for</source>
        <translation>La condition à attendre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="59"/>
        <source>If true</source>
        <translation>Si vrai</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="60"/>
        <source>What to do if the condition is met</source>
        <translation>Ce qui doit être fait si la condition est vérifiée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="63"/>
        <source>If false</source>
        <translation>Si faux</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="64"/>
        <source>What to do if the condition is not met</source>
        <translation>Ce qui doit être fait si la condition n&apos;est pas vérifiée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="68"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="69"/>
        <source>The position of the found window</source>
        <translation>La position de la fenêtre trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="72"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="73"/>
        <source>The size of the found window</source>
        <translation>La taille de la fenêtre trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="76"/>
        <source>X-coordinate</source>
        <translation>Abscisse</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="77"/>
        <source>The x-coordinate of the found window</source>
        <translation>L&apos;abscisse de la fenêtre trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="80"/>
        <source>Y-coordinate</source>
        <translation>Ordonnée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="81"/>
        <source>The y-coordinate of the found window</source>
        <translation>L&apos;ordonnée de la fenêtre trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="84"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="85"/>
        <source>The width of the found window</source>
        <translation>La largeur de la fenêtre trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="88"/>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="89"/>
        <source>The height of the found window</source>
        <translation>La hauteur de la fenêtre trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="92"/>
        <source>Process id</source>
        <translation>Identifiant de processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="93"/>
        <source>The process id of the found window</source>
        <translation>L&apos;identifiant de processus de la fenêtre trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="104"/>
        <source>Deprecated</source>
        <translation>Obsolète</translation>
    </message>
</context>
<context>
    <name>Actions::WindowDefinition</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="53"/>
        <source>Window title</source>
        <translation>Titre de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="54"/>
        <source>The title of the window to find, you can use wildcards like * (any number of characters) or ? (one character) here</source>
        <translation>Le titre de la fenêtre à trouver, vous pouvez utiliser des wildcards comme * (tout caractère) ou ? (un seul caractère) ici</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="57"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <source>The condition to wait for</source>
        <translation type="obsolete">La condition à attendre</translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="obsolete">Déplacer</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="67"/>
        <source>Move position</source>
        <translation>Position du déplacement</translation>
    </message>
    <message>
        <source>The position to move the window</source>
        <translation type="obsolete">La position où déplacer la fenêtre</translation>
    </message>
    <message>
        <source>Resize</source>
        <translation type="obsolete">Redimensionner</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="58"/>
        <source>The action to perform</source>
        <translation>L&apos;action à effectuer</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="68"/>
        <source>The position where to move the window</source>
        <translation>La position où déplacer la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="77"/>
        <source>Resize width</source>
        <translation>Nouvelle largeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="78"/>
        <source>The new width of the window</source>
        <translation>La nouvelle largeur de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="83"/>
        <source>Resize height</source>
        <translation>Nouvelle hauteur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="84"/>
        <source>The new height of the window</source>
        <translation>La nouvelle hauteur de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="89"/>
        <source>Use borders</source>
        <translation>Utiliser les bords</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="90"/>
        <source>Should the border size be taken into account when resizing the window</source>
        <translation>Les bords doivent-ils être pris en compte lors du redimensionnement de la fenêtre</translation>
    </message>
    <message>
        <source>Use borders (Windows OS only)</source>
        <translation type="obsolete">Utiliser les bordures (Windows seulement)</translation>
    </message>
    <message>
        <source>Should the border size be taken into account when resizing the window
Windows OS only, under Linux resizing is done without borders</source>
        <translation type="obsolete">Les bordures de la fenêtre doivent-elles être prises en compte lors du redimensionnement
Windows seulement, sous Linux les bordures sont ignorées</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="96"/>
        <source>Cannot find window</source>
        <translation>Impossible de trouver la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="97"/>
        <source>Action failed</source>
        <translation>Action impossible</translation>
    </message>
</context>
<context>
    <name>Actions::WindowInstance</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="78"/>
        <source>Cannot find any window matching &quot;%1&quot;</source>
        <translation>Impossible de trouver une fenêtre correspondant à &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="112"/>
        <source>&quot;%1&quot; failed</source>
        <translation>Échec de &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Code::BaseWindow</name>
    <message>
        <location filename="../actions/actionpackwindows/code/basewindow.cpp" line="82"/>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/code/basewindow.cpp" line="98"/>
        <location filename="../actions/actionpackwindows/code/basewindow.cpp" line="111"/>
        <source>Incorrect parameter type</source>
        <translation>Type de paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/code/basewindow.cpp" line="176"/>
        <source>Invalid image</source>
        <translation>Image invalide</translation>
    </message>
</context>
<context>
    <name>Code::MessageBox</name>
    <message>
        <location filename="../actions/actionpackwindows/code/messagebox.cpp" line="126"/>
        <source>Invalid image</source>
        <translation>Image invalide</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/code/messagebox.cpp" line="152"/>
        <source>Add custom button failed</source>
        <translation>Échec de l&apos;ajout de bouton personnalisé</translation>
    </message>
</context>
<context>
    <name>DataInputInstance::dataTypes</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputinstance.cpp" line="36"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputinstance.cpp" line="37"/>
        <source>Integer</source>
        <translation>Entier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputinstance.cpp" line="38"/>
        <source>Decimal</source>
        <translation>Décimal</translation>
    </message>
</context>
<context>
    <name>MessageBoxInstance::buttons</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="44"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="45"/>
        <source>Yes-No</source>
        <translation>Oui-Non</translation>
    </message>
</context>
<context>
    <name>MessageBoxInstance::icons</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="35"/>
        <source>None</source>
        <translation>Aucune</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="36"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="37"/>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="38"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="39"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>MessageBoxInstance::textmodes</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="50"/>
        <source>Automatic</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="51"/>
        <source>HTML</source>
        <translation>HTML</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxinstance.cpp" line="52"/>
        <source>Plain text</source>
        <translation>Texte brut</translation>
    </message>
</context>
<context>
    <name>MultiDataInputInstance::modes</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputinstance.cpp" line="45"/>
        <source>ComboBox</source>
        <translation>Liste déroulante</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputinstance.cpp" line="46"/>
        <source>Editable ComboBox</source>
        <translation>Liste déroulante éditable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputinstance.cpp" line="47"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputinstance.cpp" line="48"/>
        <source>CheckBox</source>
        <translation>Cases à cocher</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputinstance.cpp" line="49"/>
        <source>RadioButton</source>
        <translation>Boutons radio</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="107"/>
        <source>Message Box</source>
        <translation>Boîte de dialogue</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/messageboxdefinition.h" line="110"/>
        <source>Shows a message box</source>
        <translation>Affiche une boîte de dialogue</translation>
    </message>
    <message>
        <source>Text input</source>
        <translation type="obsolete">Entrée de texte</translation>
    </message>
    <message>
        <source>Ask the user to enter some text</source>
        <translation type="obsolete">Demande à l&apos;utilisateur d&apos;entrer du texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="97"/>
        <source>Window condition</source>
        <translation>Condition de fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditiondefinition.h" line="100"/>
        <source>Checks for the state of a window</source>
        <translation>Vérifie l&apos;état d&apos;une fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="100"/>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="103"/>
        <source>Do some action on a window</source>
        <translation>Effectue une action sur une fenêtre</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Aucune</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="obsolete">Information</translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="obsolete">Question</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Avertissement</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Erreur</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="obsolete">Ok</translation>
    </message>
    <message>
        <source>Yes-No</source>
        <translation type="obsolete">Oui-Non</translation>
    </message>
    <message>
        <source>Created</source>
        <translation type="obsolete">Créé</translation>
    </message>
    <message>
        <source>Closed</source>
        <translation type="obsolete">Fermé</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Fermer</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation type="obsolete">Fermer processus</translation>
    </message>
    <message>
        <source>Set foreground</source>
        <translation type="obsolete">Mettre au premier plan</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation type="obsolete">Minimiser</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation type="obsolete">Maximiser</translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="obsolete">Déplacer</translation>
    </message>
    <message>
        <source>Resize</source>
        <translation type="obsolete">Redimensionner</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="79"/>
        <source>Data input</source>
        <translation>Entrée de donnée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/datainputdefinition.h" line="82"/>
        <source>Ask the user to enter some data</source>
        <translation>Demande à l&apos;utilisateur d&apos;entrer une donnée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="100"/>
        <source>Multi data input</source>
        <translation>Liste de sélection</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/multidatainputdefinition.h" line="103"/>
        <source>Ask the user to choose from a list</source>
        <translation>Demande à l&apos;utilisateur de faire un choix parmi une liste</translation>
    </message>
</context>
<context>
    <name>WindowConditionInstance::conditions</name>
    <message>
        <source>Created</source>
        <translation type="obsolete">Créée</translation>
    </message>
    <message>
        <source>Closed</source>
        <translation type="obsolete">Fermée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditioninstance.cpp" line="32"/>
        <source>Exists</source>
        <translation>Existe</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowconditioninstance.cpp" line="33"/>
        <source>Don&apos;t exists</source>
        <translation>N&apos;existe pas</translation>
    </message>
</context>
<context>
    <name>WindowInstance::actions</name>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="31"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="32"/>
        <source>Kill process</source>
        <translation>Fermer processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="33"/>
        <source>Set foreground</source>
        <translation>Mettre au premier plan</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="34"/>
        <source>Minimize</source>
        <translation>Minimiser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="35"/>
        <source>Maximize</source>
        <translation>Maximiser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="36"/>
        <source>Move</source>
        <translation>Déplacer</translation>
    </message>
    <message>
        <location filename="../actions/actionpackwindows/actions/windowinstance.cpp" line="37"/>
        <source>Resize</source>
        <translation>Redimensionner</translation>
    </message>
</context>
</TS>
